append_thread_name

Function append_thread_name 

pub async fn append_thread_name(
    codex_home: &Path,
    thread_id: ThreadId,
    name: &str,
) -> Result<()>
Append a thread name update to the session index. Name updates are append-only; the most recent entry wins when resolving names or ids.