get_threads

Function get_threads 

pub async fn get_threads(
    codex_home: &Path,
    page_size: usize,
    cursor: Option<&Cursor>,
    sort_key: ThreadSortKey,
    allowed_sources: &[SessionSource],
    model_providers: Option<&[String]>,
    cwd_filters: Option<&[PathBuf]>,
    default_provider: &str,
) -> Result<ThreadsPage>
Retrieve recorded thread file paths with token pagination. The returned next_cursor can be supplied on the next call to resume after the last returned item, resilient to concurrent new sessions being appended. Ordering is stable by the requested sort key (timestamp desc).