pub struct SessionMeta {Show 23 fields
pub session_id: SessionId,
pub id: ThreadId,
pub forked_from_id: Option<ThreadId>,
pub parent_thread_id: Option<ThreadId>,
pub timestamp: String,
pub cwd: PathBuf,
pub originator: String,
pub cli_version: String,
pub source: SessionSource,
pub thread_source: Option<ThreadSource>,
pub agent_nickname: Option<String>,
pub agent_role: Option<String>,
pub agent_path: Option<String>,
pub model_provider: Option<String>,
pub base_instructions: Option<BaseInstructions>,
pub dynamic_tools: Option<Vec<DynamicToolSpec>>,
pub selected_capability_roots: Vec<SelectedCapabilityRoot>,
pub memory_mode: Option<String>,
pub history_mode: ThreadHistoryMode,
pub history_base: Option<HistoryPosition>,
pub subagent_history_start_ordinal: Option<u64>,
pub multi_agent_version: Option<MultiAgentVersion>,
pub context_window: Option<SessionContextWindow>,
}Expand description
SessionMeta contains session-level data that doesn’t correspond to a specific turn.
NOTE: There used to be an instructions field here, which stored user_instructions, but we
now save that on TurnContext. base_instructions stores the base instructions for the session,
and should be used when there is no config override.
Fields
session_id: SessionIdid: ThreadIdforked_from_id: Option<ThreadId>parent_thread_id: Option<ThreadId>timestamp: Stringcwd: PathBuforiginator: Stringcli_version: Stringsource: SessionSourcethread_source: Option<ThreadSource>Optional analytics source classification for this thread.
agent_nickname: Option<String>Optional random unique nickname assigned to an AgentControl-spawned sub-agent.
agent_role: Option<String>Optional role (agent_role) assigned to an AgentControl-spawned sub-agent.
agent_path: Option<String>Optional canonical agent path assigned to an AgentControl-spawned sub-agent.
model_provider: Option<String>base_instructions: Option<BaseInstructions>base_instructions for the session. This should always be present when creating a new session, but may be missing for older sessions. If not present, fall back to rendering the base_instructions from ModelsManager.
dynamic_tools: Option<Vec<DynamicToolSpec>>selected_capability_roots: Vec<SelectedCapabilityRoot>Capability roots selected for this thread by the hosting platform.
memory_mode: Option<String>history_mode: ThreadHistoryModehistory_base: Option<HistoryPosition>Exclusive prefix of another paginated rollout inherited by this thread.
subagent_history_start_ordinal: Option<u64>First rollout ordinal that belongs to this subagent’s own projected history.
Earlier rollout records are inherited model context and stay out of child turn/item projection.
multi_agent_version: Option<MultiAgentVersion>context_window: Option<SessionContextWindow>Initial context-window identity for consumers that tail rollout JSONL before compaction.